@@ -4,7 +4,7 @@ from pylav.filters.utils import FilterMixin
 
 
 class Karaoke(FilterMixin):
-    __slots__ = ("_level", "_mono_level", "_filter_band", "_filter_width", "_off", "_default")
+    __slots__ = ("_level", "_mono_level", "_filter_band", "_filter_width", "_default")
 
     def __init__(
         self, level: float = None, mono_level: float = None, filter_band: float = None, filter_width: float = None
@@ -14,18 +14,8 @@ class Karaoke(FilterMixin):
         self.mono_level = mono_level
         self.filter_band = filter_band
         self.filter_width = filter_width
-        self.off = all(v is None for v in [level, mono_level, filter_band, filter_width])
 
     def to_dict(self) -> dict[str, float | bool | None]:
-        return {
-            "level": self.level,
-            "mono_level": self.mono_level,
-            "filter_band": self.filter_band,
-            "filter_width": self.filter_width,
-            "off": self.off,
-        }
-
-    def to_json(self) -> dict[str, float | None]:
         return {
             "level": self.level,
             "mono_level": self.mono_level,
@@ -35,14 +25,12 @@ class Karaoke(FilterMixin):
 
     @classmethod
     def from_dict(cls, data: dict[str, float | bool | None]) -> Karaoke:
-        c = cls(
+        return cls(
             level=data["level"],
             mono_level=data["mono_level"],
             filter_band=data["filter_band"],
             filter_width=data["filter_width"],
         )
-        c.off = data["off"]
-        return c
 
     def __repr__(self):
         return (
@@ -57,10 +45,6 @@ class Karaoke(FilterMixin):
     @level.setter
     def level(self, v: float | None):
         self._level = v
-        self.off = all(
-            v is None
-            for v in [getattr(self, attr, None) for attr in self.__slots__ if attr not in {"_off", "_default"}]
-        )
 
     @property
     def mono_level(self) -> float | None:
@@ -69,10 +53,6 @@ class Karaoke(FilterMixin):
     @mono_level.setter
     def mono_level(self, v: float | None):
         self._mono_level = v
-        self.off = all(
-            v is None
-            for v in [getattr(self, attr, None) for attr in self.__slots__ if attr not in {"_off", "_default"}]
-        )
 
     @property
     def filter_band(self) -> float | None:
@@ -81,10 +61,6 @@ class Karaoke(FilterMixin):
     @filter_band.setter
     def filter_band(self, v: float | None):
         self._filter_band = v
-        self.off = all(
-            v is None
-            for v in [getattr(self, attr, None) for attr in self.__slots__ if attr not in {"_off", "_default"}]
-        )
 
     @property
     def filter_width(self) -> float:
@@ -93,10 +69,6 @@ class Karaoke(FilterMixin):
     @filter_width.setter
     def filter_width(self, v: float | None):
         self._filter_width = v
-        self.off = all(
-            v is None
-            for v in [getattr(self, attr, None) for attr in self.__slots__ if attr not in {"_off", "_default"}]
-        )
 
     @classmethod
     def default(cls) -> Karaoke:
@@ -118,4 +90,3 @@ class Karaoke(FilterMixin):
 
     def reset(self) -> None:
         self.level = self.mono_level = self.filter_band = self.filter_width = None
-        self.off = True
